@@ -86,8 +86,16 @@ Changelog
 0.0.81: add: add support for Python 3.11
 0.0.82: fix: fix connection.py
 0.0.83: fix: fix Dockerfile
+0.0.84: fix: fix homepage url
+0.0.85: fix: update python version
+0.0.86: add: add log function
+0.0.87: fix: fix update python 3.13
+0.0.88: fix: fix update typer deps
+0.0.89: fix: fix get_latest_version
+0.0.90: fix: fix get_latest_version
+0.0.91: fix: fix update python 3.14
 """
 
 __title__ = "AKTools"
-__version__ = "0.0.83"
+__version__ = "0.0.91"
 __author__ = "AKFamily"
