@@ -1,7 +1,7 @@
 # -*- coding:utf-8 -*-
 # /usr/bin/env python
 """
-Date: 2021/12/9 17:20
+Date: 2025/10/29 17:20
 Desc: Just for test file
 """
 import akshare as ak
@@ -13,8 +13,8 @@ def test_demo():
     :return: Error
     :rtype: assert result
     """
-    cost_living_df = ak.cost_living()
-    assert cost_living_df.shape[0] != 0
+    stock_zh_a_hist_df = ak.stock_zh_a_hist()
+    assert stock_zh_a_hist_df.shape[0] != 0
 
 
 if __name__ == "__main__":
